Documentation — django-smartspaceless 0.1 documentation

# Documentation

Full documentation is available online.

However, you can also build the documentation from source. Enter your virtual environment.

    $ workon myvenv

Clone the code repository.

    $ git clone git@github.com:richardcornish/django-smartspaceless.git
    $ cd django-smartspaceless/

Install Sphinx, `sphinx-autobuild`, and `sphinx_rtd_theme`.

    $ pip install sphinx sphinx-autobuild sphinx_rtd_theme

Create an HTML build.

    $ (cd docs/ && make html)

Or use `sphinx-autobuild` to watch for live changes.

    $ sphinx-autobuild docs/ docs/_build_html

Open 127.0.0.1:8000.